#!/bin/bash
set -e

echo "### PROGRESS: Installing monitoring tools..."
sudo apt-get update -qq
sudo apt-get install -y -qq sysstat jq

# Enable sar data collection
sudo sed -i 's/ENABLED="false"/ENABLED="true"/' /etc/default/sysstat 2>/dev/null || true

# Create working directory
mkdir -p /tmp/experiment_data

echo "### PROGRESS: Monitoring tools installed."
